package
Version:
v0.1.0
Opens a new window with list of versions in this module.
Published: Oct 31, 2024
License: Apache-2.0
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func (l *Link) Pop() (interface{}, bool)
func (l *Link) Push(data interface{})
type Storager interface {
Push(interface{})
Pop() (interface{}, bool)
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.